==> mpvue-page-3.0.0.tgz: package/bin/page.js <==
#!/usr/bin/env node
var program = require('commander');
var appInfo = require('./../package.json');
var fs = require('fs-extra')

program
    .version(appInfo.version)
    .usage('<command> [options]')

//像git风格一样的子命令
program
    //子命令
    .command('init <cmd>')
    //短命令 - 简写方式
    .alias('i')
    //说明
    .description('创建模板')
    //注册一个callback函数
    .action(function (cmd, options) {
        var nm = typeof options.name == 'string' ? options.name : ""

        const appjson = "./src/app.json"
        fs.pathExists(appjson).then(exists => {
            if (exists == true) {
                fs.readJSON(appjson).then(appObj => {
                    let pageUrl = "pages/" + cmd + "/main"
                    if (appObj.pages.indexOf(pageUrl) < 0) {
                        let newdir = "./src/pages/" + cmd
                        fs.copy('./template/page', newdir, function (err) {
                            if (err) return console.error(err)
                            appObj.pages.push(pageUrl)
                            fs.writeJson(appjson, appObj)
                                .then(() => {
                                    console.log('success!')
                                })
                        });

                    }
                    else {
                        console.log("创建失败，文件已经存在");
                    }
                })
            }
            else{
                console.log('抱歉，找不到app.json');    
            }
        })
    })

program.parse(process.argv);

==> mpvue-page-3.0.1.tgz: package/bin/page.js <==
#!/usr/bin/env node
var program = require('commander');
var appInfo = require('./../package.json');
var fs = require('fs-extra')

program
    .version(appInfo.version)
    .usage('<command> [options]')

//像git风格一样的子命令
program
    //子命令
    .command('init <cmd>')
    //短命令 - 简写方式
    .alias('i')
    //说明
    .description('创建模板')
    //注册一个callback函数
    .action(function (cmd, options) {
        var nm = typeof options.name == 'string' ? options.name : ""

        const appjson = "/src/app.json"
        fs.pathExists(appjson).then(exists => {
            if (exists == true) {
                fs.readJSON(appjson).then(appObj => {
                    let pageUrl = "pages/" + cmd + "/main"
                    if (appObj.pages.indexOf(pageUrl) < 0) {
                        let newdir = "src/pages/" + cmd
                        fs.copy('/node_modules/mpvue-page/template/page', newdir, function (err) {
                            if (err) return console.error(err)
                            appObj.pages.push(pageUrl)
                            fs.writeJson(appjson, appObj)
                                .then(() => {
                                    console.log('success!')
                                })
                        });

                    }
                    else {
                        console.log("创建失败，文件已经存在");
                    }
                })
            }
            else{
                console.log('抱歉，找不到app.json');    
            }
        })
    })

program.parse(process.argv);
